# GBNF

<a href="https://pypi.org/project/gbnf"><img alt="Latest GBNF PyPI Version" src="https://badge.fury.io/py/gbnf.svg" /></a>
<a href="https://github.com/ambient-labs/GBNF/packages/gbnf/blob/master/LICENSE"><img alt="License for gbnf" src="https://img.shields.io/pypi/l/gbnf" /></a>
<a href="https://pypi.org/project/gbnf"><img alt="Downloads per week on PyPI for gbnf" src="https://img.shields.io/pypi/dw/gbnf" /></a>
<a href="https://github.com/ambient-labs/GBNF/packages/gbnf/actions/workflows/tests.yaml"><img src="https://github.com/ambient-labs/GBNF/packages/gbnf/actions/workflows/tests.yaml/badge.svg" alt="Status of tests for gbnf repository" /></a>
<a href="https://codecov.io/gh/ambient-labs/gbnf"><img alt="Code Coverage for gbnf" src="https://img.shields.io/codecov/c/github/ambient-labs/gbnf" /></a>
<a href="https://deepsource.io/gh/ambient-labs/gbnf/?ref=repository-badge"><img alt="DeepSource issues for gbnf" src="https://deepsource.io/gh/ambient-labs/gbnf.svg/?label=active+issues&show_trend=true" /></a>

A library for parsing `.gbnf` grammar files in Python.

## Install

```bash
pip install gbnf
```
